Summary: A high performance compressor optimized for binary data
Name: blosc
Version: 1.2.3
Release: 2%{?dist}
License: MIT
Source: http://blosc.org/sources/%{version}/%{name}-%{version}.tar.gz
URL:  http://blosc.org
BuildRequires: cmake

%description
It has been designed to transmit data to the processor cache 
faster than the traditional, non-compressed, direct memory fetch 
approach via a memcpy() OS call. Blosc is the first compressor 
(that I'm aware of) that is meant not only to reduce the size of 
large datasets on-disk or in-memory, but also to accelerate 
memory-bound computations 

%package devel
Summary: Header files and libraries for Blosc development
Requires: %{name} = %{version}-%{release}

%description devel
The blosc-devel package contains the header files and libraries needed
to develop programs that use the blosc meta-compressor.

%prep
%setup -q

# Use the proper library path and SSE2 instruction on 64bits systems
%ifarch x86_64
cmake %{?_cmake_lib_suffix64} \
    -DCMAKE_C_FLAGS:STRING="%{optflags} -msse2" \
    -DCMAKE_INSTALL_PREFIX=%{_prefix} \
    -DBUILD_STATIC:BOOL=OFF \
    -DTEST_INCLUDE_BENCH_SUITE:BOOL=OFF .
%else
cmake -DCMAKE_C_FLAGS:STRING="%{optflags}" \
    -DCMAKE_INSTALL_PREFIX=%{_prefix} \
    -DBUILD_STATIC:BOOL=OFF \
    -DTEST_INCLUDE_BENCH_SUITE:BOOL=OFF .
%endif

# Fix library version
sed -i 's|BLOSC_VERSION_MINOR 1|BLOSC_VERSION_MINOR 2|' CMakeLists.txt
sed -i 's|BLOSC_VERSION_PATCH 6|BLOSC_VERSION_PATCH 6|' CMakeLists.txt


%build
make VERBOSE=1 %{?_smp_mflags}

%check
make test VERBOSE=1

%install

make install DESTDIR=${RPM_BUILD_ROOT}

mkdir -p ${RPM_BUILD_ROOT}/%{_docdir}/bench
cp -pr bench/plot-speeds.py* ${RPM_BUILD_ROOT}/%{_docdir}/bench
cp -pr bench/*.c ${RPM_BUILD_ROOT}/%{_docdir}/bench

%clean
rm -rf ${RPM_BUILD_ROOT}

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%doc README.rst ANNOUNCE.rst RELEASE_NOTES.rst README_HEADER.rst README_THREADED.rst RELEASING.rst
%{_libdir}/libblosc.so.*

%files devel
%{_libdir}/libblosc.so
%{_includedir}/blosc.h
%{_docdir}/bench/plot-speeds.py*
%{_docdir}/bench/*.c


%changelog
* Wed Oct 16 2013 Thibault North <tnorth@fedoraproject.org> - 1.2.3-2
- Various fixes

* Fri Sep 20 2013 Thibault North <tnorth@fedoraproject.org> - 1.2.3-1
- Sync upstream

* Fri Mar 22 2013 Thibault North <tnorth@fedoraproject.org> - 1.1.6-1
- Initial package
